@@ -1,18 +1,14 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 use Rope::Object;
+use Rope::Pro;
 my (%META, %PRO);
 our @ISA;
 
 BEGIN {
-	%PRO = (
-		keyword => sub {
-			my ($caller, $method, $cb) = @_;
-			no strict 'refs';
-			*{"${caller}::${method}"} = $cb;
-		},
+	%PRO = Rope::Pro->new(
 		scope => sub {
 			my ($caller, $self, %props) = @_;
 			for my $prop (keys %{$props{properties}}) {
@@ -630,7 +626,7 @@ Rope - Tied objects
 
 =head1 VERSION
 
-Version 0.38
+Version 0.39
 
 =cut
 
