@@ -2,17 +2,12 @@ package Rope::Factory;
 
 use Factory::Sub;
 use Coerce::Types::Standard;
+use Rope::Pro;
 
 my (%PRO);
 
 BEGIN {
-	%PRO = (
-		keyword => sub {
-			my ($caller, $method, $cb) = @_;
-			no strict 'refs';
-			*{"${caller}::${method}"} = $cb;
-		},
-	);
+	%PRO = Rope::Pro->new;
 }
 
 sub import {
@@ -74,7 +69,7 @@ Rope::Factory - Rope factory properties
 
 =head1 VERSION
 
-Version 0.38
+Version 0.39
 
 =cut
 
