@@ -1,16 +1,11 @@
 package Rope::Type;
 
 use Types::Standard;
-
+use Rope::Pro;
 my (%PRO);
 
 BEGIN {
-	%PRO = (
-		keyword => sub {
-			my ($caller, $method, $cb) = @_;
-			no strict 'refs';
-			*{"${caller}::${method}"} = $cb;
-		},
+	%PRO = Rope::Pro->new(
 		type_map => {
 			int => 'Int',
 			bool => 'Bool',
@@ -63,7 +58,7 @@ Rope::Type - Rope with Type::Tiny
 
 =head1 VERSION
 
-Version 0.38
+Version 0.39
 
 =cut
 
